Home
last modified time | relevance | path

Searched refs:lds (Results 1 – 25 of 26) sorted by relevance

12

/freebsd/contrib/llvm-project/llvm/lib/Target/AMDGPU/
H A DDSDIRInstructions.td110 class DSDIR_Real<DSDIR_Pseudo lds, dag ins, string asm, int subtarget> :
111 DSDIR_Common<lds.Mnemonic,
112 lds.Mnemonic # asm,
114 lds.is_direct>,
115 SIMCInstr <lds.PseudoInstr, subtarget> {
120 let SubtargetPredicate = lds.SubtargetPredicate;
166 defvar lds = !cast<DSDIR_Pseudo>(NAME);
167 def _gfx11 : DSDIR_Real<lds, lds.InOperandList,
168 LDSDIR_getAsm<lds.is_direct>.ret,
170 LDSDIRe<op, lds.is_direct> {
[all …]
H A DLDSDIRInstructions.td
H A DAMDGPUPassRegistry.def24 MODULE_PASS("amdgpu-lower-module-lds", AMDGPULowerModuleLDSPass(*this))
31 MODULE_PASS("amdgpu-sw-lower-lds", AMDGPUSwLowerLDSPass(*this))
H A DAMDGPUAttributes.def30 AMDGPU_ATTRIBUTE(LDS_KERNEL_ID, "amdgpu-no-lds-kernel-id")
H A DFLATInstructions.td69 bits<1> lds = 0;
126 bits<1> lds = ps.lds; // LDS DMA for global and scratch
142 let Inst{13} = !if(ps.has_sve, ps.sve, lds);
353 let lds = 1;
436 let lds = 0;
596 let lds = 1;
2140 let AsmString = pre_gfx940_name # !cast<FLAT_Pseudo>(NAME).AsmOperands # " lds";
2143 let AsmString = pre_gfx940_name # !cast<FLAT_Pseudo>(NAME#"_SADDR").AsmOperands # " lds";
2437 let AsmString = opname # !cast<FLAT_Pseudo>(NAME).AsmOperands # " lds" in
2440 let AsmString = opname # !cast<FLAT_Pseudo>(NAME#"_SADDR").AsmOperands # " lds" in
[all …]
H A DAMDGPU.td217 def FeatureLdsMisalignedBug : SubtargetFeature<"lds-misaligned-bug",
265 def FeatureLdsBranchVmemWARHazard : SubtargetFeature<"lds-branch-vmem-war-hazard",
1340 def FeatureMemToLDSLoad : SubtargetFeature<"vmem-to-lds-load-insts",
1343 …"The platform has memory to lds instructions (global_load w/lds bit set, buffer_load w/lds bit set…
1346 def FeatureLdsBarrierArriveAtomic : SubtargetFeature< "lds-barrier-arrive-atomic",
H A DBUFInstructions.td80 bits<1> lds = 0;
81 bits<1> has_vdata = !not(lds);
458 string Lds = !if(isLds, " lds", "");
516 let lds = isLds;
665 " $srsrc, $soffset$offset lds$cpol"> {
672 let lds = 1;
2355 let Inst{16} = ps.lds;
3036 let Inst{16} = ps.lds;
3149 let Inst{16} = ps.lds;
/freebsd/usr.sbin/pmcstudy/
H A Dpmcstudy.c1473 double un, lds, con, res; in aliasing() local
1479 lds = ld->vals[pos] * 1.0; in aliasing()
1482 lds = ld->sum * 1.0; in aliasing()
1485 res = (lds * con)/un; in aliasing()
1497 double un, lds, con, res; in aliasing_broad() local
1503 lds = ld->vals[pos] * 1.0; in aliasing_broad()
1506 lds = ld->sum * 1.0; in aliasing_broad()
1509 res = (lds * con)/un; in aliasing_broad()
/freebsd/sys/modules/linux64/
H A DMakefile83 -T${SRCTOP}/sys/${MACHINE}/linux/linux_vdso.lds.s \
/freebsd/contrib/processor-trace/libipt/test/src/
H A Dptunit-ild.c563 static struct ptunit_result lds(void) in lds() function
742 ptu_run(suite, lds); in main()
/freebsd/sys/modules/linux/
H A DMakefile118 -T${SRCTOP}/sys/${MACHINE}/linux${SFX}/linux${SFX}_vdso.lds.s \
/freebsd/sys/compat/linux/
H A Dlinux_ioctl.c1666 l_dvd_struct *lds; in linux_ioctl_cdrom() local
1669 lds = malloc(sizeof(*lds), M_LINUX, M_WAITOK); in linux_ioctl_cdrom()
1671 error = copyin((void *)args->arg, lds, sizeof(*lds)); in linux_ioctl_cdrom()
1674 error = linux_to_bsd_dvd_struct(lds, bds); in linux_ioctl_cdrom()
1681 error = bsd_to_linux_dvd_struct(bds, lds); in linux_ioctl_cdrom()
1684 error = copyout(lds, (void *)args->arg, sizeof(*lds)); in linux_ioctl_cdrom()
1687 free(lds, M_LINUX); in linux_ioctl_cdrom()
/freebsd/sys/contrib/openzfs/config/
H A Dlib-ld.m415 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
/freebsd/contrib/llvm-project/clang/include/clang/Basic/
H A DBuiltinsAMDGPU.def166 TARGET_BUILTIN(__builtin_amdgcn_raw_ptr_buffer_load_lds, "vQbv*3IUiiiIiIi", "t", "vmem-to-lds-load-…
260 TARGET_BUILTIN(__builtin_amdgcn_load_to_lds, "vv*v*3IUiIiIUi", "", "vmem-to-lds-load-insts")
261 TARGET_BUILTIN(__builtin_amdgcn_global_load_lds, "vv*1v*3IUiIiIUi", "t", "vmem-to-lds-load-insts")
/freebsd/contrib/llvm-project/llvm/lib/Target/AVR/
H A DAVRInstrInfo.td875 def LDSRdK : F32DM<0b0, (outs GPR8:$rd), (ins imm16:$k), "lds\t$rd, $k",
881 "lds\t$rd, $k", [(set i8:$rd, (load imm:$k))]>,
887 // lds Rd, (K+1:K)
888 // lds Rd+1 (K+1:K) + 1
H A DAVRInstrFormats.td495 // i = 0 - lds, 1 - sts
/freebsd/contrib/llvm-project/llvm/lib/Target/X86/
H A DX86InstrSystem.td350 "lds{w}\t{$src, $dst|$dst, $src}", []>, OpSize16,
353 "lds{l}\t{$src, $dst|$dst, $src}", []>, OpSize32,
/freebsd/contrib/llvm-project/llvm/include/llvm/IR/
H A DIntrinsicsAMDGPU.td2124 // This intrinsic reads from lds, but the memory values are constant,
2160 // llvm.amdgcn.lds.direct.load <m0>
2168 // llvm.amdgcn.lds.param.load <attr_chan>, <attr>, <m0>
2169 // Like interp intrinsics, this reads from lds, but the memory values are constant,
/freebsd/contrib/openpam/m4/
H A Dlibtool.m43469 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5674 # We only use this code for GNU lds that support --whole-archive.
6754 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/file/m4/
H A Dlibtool.m43360 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5534 # We only use this code for GNU lds that support --whole-archive.
6608 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/openbsm/m4/
H A Dlibtool.m43340 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5513 # We only use this code for GNU lds that support --whole-archive.
6586 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/ntp/sntp/libevent/m4/
H A Dlibtool.m43340 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5513 # We only use this code for GNU lds that support --whole-archive.
6586 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/ntp/sntp/m4/
H A Dlibtool.m43340 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5513 # We only use this code for GNU lds that support --whole-archive.
6586 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/libevent/m4/
H A Dlibtool.m43361 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5535 # We only use this code for GNU lds that support --whole-archive.
6609 # We only use this code for GNU lds that support --whole-archive.
/freebsd/contrib/ldns/m4/
H A Dlibtool.m43371 [# I'd rather use --version here, but apparently some GNU lds only accept -v.
5559 # We only use this code for GNU lds that support --whole-archive.
6635 # We only use this code for GNU lds that support --whole-archive.

12